@@ -1,10 +1,9 @@
 """Module provider for DNSPod"""
-from __future__ import absolute_import
-
 import logging
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
@@ -31,7 +30,7 @@ class Provider(BaseProvider):
         payload = self._post("/Domain.Info", {"domain": self.domain})
 
         if payload["status"]["code"] != "1":
-            raise Exception(payload["status"]["message"])
+            raise AuthenticationError(payload["status"]["message"])
 
         self.domain_id = payload["domain"]["id"]
 
