@@ -1,10 +1,9 @@
 """Module provider for Glesys"""
-from __future__ import absolute_import
-
 import json
 
 import requests
 
+from lexicon.exceptions import AuthenticationError
 from lexicon.providers.base import Provider as BaseProvider
 
 NAMESERVER_DOMAINS = ["glesys.com"]
@@ -33,9 +32,8 @@ class Provider(BaseProvider):
                 # Since domain_id cannot be None, use domain name as id instead.
                 self.domain_id = record["domainname"]
                 break
-
-        if self.domain_id is None:
-            raise Exception("No domain found")
+        else:
+            raise AuthenticationError("No domain found")
 
     # Create record. If record already exists with the same content, do nothing.
     def _create_record(self, rtype, name, content):
